import * as cloudwatch from '../../aws-cloudwatch';
import { Construct } from 'constructs';
/**
 * Types of OpsItem severity available.
 *
 * @stability stable
 */
export declare enum OpsItemSeverity {
    /**
     * Set the severity to critical.
     *
     * @stability stable
     */
    CRITICAL = "1",
    /**
     * Set the severity to high.
     *
     * @stability stable
     */
    HIGH = "2",
    /**
     * Set the severity to medium.
     *
     * @stability stable
     */
    MEDIUM = "3",
    /**
     * Set the severity to low.
     *
     * @stability stable
     */
    LOW = "4"
}
/**
 * Types of OpsItem category available.
 *
 * @stability stable
 */
export declare enum OpsItemCategory {
    /**
     * Set the category to availability.
     *
     * @stability stable
     */
    AVAILABILITY = "Availability",
    /**
     * Set the category to cost.
     *
     * @stability stable
     */
    COST = "Cost",
    /**
     * Set the category to performance.
     *
     * @stability stable
     */
    PERFORMANCE = "Performance",
    /**
     * Set the category to recovery.
     *
     * @stability stable
     */
    RECOVERY = "Recovery",
    /**
     * Set the category to security.
     *
     * @stability stable
     */
    SECURITY = "Security"
}
/**
 * Use an SSM OpsItem action as an Alarm action.
 *
 * @stability stable
 */
export declare class SsmAction implements cloudwatch.IAlarmAction {
    private severity;
    private category?;
    /**
     * @stability stable
     */
    constructor(severity: OpsItemSeverity, category?: OpsItemCategory);
    /**
     * Returns an alarm action configuration to use an SSM OpsItem action as an alarm action.
     *
     * @stability stable
     */
    bind(_scope: Construct, _alarm: cloudwatch.IAlarm): cloudwatch.AlarmActionConfig;
}
