import { Step } from './step';
/**
 * A set of files traveling through the deployment pipeline.
 *
 * Individual steps in the pipeline produce or consume
 * `FileSet`s.
 *
 * @stability stable
 */
export declare class FileSet implements IFileSetProducer {
    /** Human-readable descriptor for this file set (does not need to be unique) */
    readonly id: string;
    /**
     * The primary output of a file set producer.
     *
     * The primary output of a FileSet is itself.
     *
     * @stability stable
     */
    readonly primaryOutput?: FileSet;
    private _producer?;
    /**
     * @param id Human-readable descriptor for this file set (does not need to be unique).
     * @stability stable
     */
    constructor(
    /** Human-readable descriptor for this file set (does not need to be unique) */
    id: string, producer?: Step);
    /**
     * The Step that produces this FileSet.
     *
     * @stability stable
     */
    get producer(): Step;
    /**
     * Mark the given Step as the producer for this FileSet.
     *
     * This method can only be called once.
     *
     * @stability stable
     */
    producedBy(producer?: Step): void;
    /**
     * Return a string representation of this FileSet.
     *
     * @stability stable
     */
    toString(): string;
}
/**
 * Any class that produces, or is itself, a `FileSet`.
 *
 * Steps implicitly produce a primary FileSet as an output.
 *
 * @stability stable
 */
export interface IFileSetProducer {
    /**
     * The `FileSet` produced by this file set producer.
     *
     * @default - This producer doesn't produce any file set
     * @stability stable
     */
    readonly primaryOutput?: FileSet;
}
